==> certmanager-model-v1beta1-6.4.1-sources.jar: io/fabric8/certmanager/api/model/acme/v1beta1/ACMEIssuerStatusFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEIssuerStatusFluentImpl<A extends ACMEIssuerStatusFluent<A>> extends BaseFluent<A> implements ACMEIssuerStatusFluent<A>{
  public ACMEIssuerStatusFluentImpl() {
  }
  public ACMEIssuerStatusFluentImpl(ACMEIssuerStatus instance) {
    this.withLastRegisteredEmail(instance.getLastRegisteredEmail()); 
    this.withUri(instance.getUri()); 
  }
  private String lastRegisteredEmail;
  private String uri;
  public String getLastRegisteredEmail() {
    return this.lastRegisteredEmail;
  }
  public A withLastRegisteredEmail(String lastRegisteredEmail) {
    this.lastRegisteredEmail=lastRegisteredEmail; return (A) this;
  }
  public Boolean hasLastRegisteredEmail() {
    return this.lastRegisteredEmail != null;
  }
  public String getUri() {
    return this.uri;
  }
  public A withUri(String uri) {
    this.uri=uri; return (A) this;
  }
  public Boolean hasUri() {
    return this.uri != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ACMEIssuerStatusFluentImpl that = (ACMEIssuerStatusFluentImpl) o;
    if (lastRegisteredEmail != null ? !lastRegisteredEmail.equals(that.lastRegisteredEmail) :that.lastRegisteredEmail != null) return false;
    if (uri != null ? !uri.equals(that.uri) :that.uri != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(lastRegisteredEmail,  uri,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (lastRegisteredEmail != null) { sb.append("lastRegisteredEmail:"); sb.append(lastRegisteredEmail + ","); }
    if (uri != null) { sb.append("uri:"); sb.append(uri); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> certmanager-model-v1beta1-6.7.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1beta1/ACMEIssuerStatusFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEIssuerStatusFluentImpl<A extends ACMEIssuerStatusFluent<A>> extends BaseFluent<A> implements ACMEIssuerStatusFluent<A>{
  public ACMEIssuerStatusFluentImpl() {
  }
  public ACMEIssuerStatusFluentImpl(ACMEIssuerStatus instance) {
    if (instance != null) {
      this.withLastRegisteredEmail(instance.getLastRegisteredEmail());
      this.withUri(instance.getUri());
    }
  }
  private String lastRegisteredEmail;
  private String uri;
  public String getLastRegisteredEmail() {
    return this.lastRegisteredEmail;
  }
  public A withLastRegisteredEmail(String lastRegisteredEmail) {
    this.lastRegisteredEmail=lastRegisteredEmail; return (A) this;
  }
  public Boolean hasLastRegisteredEmail() {
    return this.lastRegisteredEmail != null;
  }
  public String getUri() {
    return this.uri;
  }
  public A withUri(String uri) {
    this.uri=uri; return (A) this;
  }
  public Boolean hasUri() {
    return this.uri != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEIssuerStatusFluentImpl that = (ACMEIssuerStatusFluentImpl) o;
    if (!java.util.Objects.equals(lastRegisteredEmail, that.lastRegisteredEmail)) return false;

    if (!java.util.Objects.equals(uri, that.uri)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(lastRegisteredEmail,  uri,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (lastRegisteredEmail != null) { sb.append("lastRegisteredEmail:"); sb.append(lastRegisteredEmail + ","); }
    if (uri != null) { sb.append("uri:"); sb.append(uri); }
    sb.append("}");
    return sb.toString();
  }
  
}
